rpms/colossus/F-10 .cvsignore, 1.5, 1.6 colossus-gen-tarball.sh, 1.1, 1.2 colossus.spec, 1.6, 1.7 import.log, 1.4, 1.5 sources, 1.5, 1.6

Bruno Wolff III bruno at fedoraproject.org
Sat Oct 17 00:58:34 UTC 2009


Author: bruno

Update of /cvs/pkgs/rpms/colossus/F-10
In directory cvs1.fedora.phx.redhat.com:/tmp/cvs-serv12026/F-10

Modified Files:
	.cvsignore colossus-gen-tarball.sh colossus.spec import.log 
	sources 
Log Message:
Rebase to 0.9.3



Index: .cvsignore
===================================================================
RCS file: /cvs/pkgs/rpms/colossus/F-10/.cvsignore,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -p -r1.5 -r1.6
--- .cvsignore	6 Sep 2009 16:49:48 -0000	1.5
+++ .cvsignore	17 Oct 2009 00:58:34 -0000	1.6
@@ -1 +1 @@
-colossus-20090906-4519.tar.gz
+colossus-0.9.3-20091015-4577.tar.gz


Index: colossus.spec
===================================================================
RCS file: /cvs/pkgs/rpms/colossus/F-10/colossus.spec,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -p -r1.6 -r1.7
--- colossus.spec	6 Sep 2009 16:49:49 -0000	1.6
+++ colossus.spec	17 Oct 2009 00:58:34 -0000	1.7
@@ -1,8 +1,9 @@
 Name:           colossus
-%define         rev        4519
-%define         revdate    20090906
-Version:        0.9.2
-Release:        1.%{revdate}svn%{rev}%{?dist}
+%define         rev        4577
+%define         revdate    20091015
+Version:        0.9.3
+%define         branch     %{version}
+Release:        1%{?dist}
 Summary:        Allows people to play Titan against each other or AIs
 
 Group:          Amusements/Games
@@ -17,7 +18,7 @@ URL:            http://colossus.sourcefo
 # when grabbing the latest revision, using svn info.
 # The repo is at:
 # https://colossus.svn.sourceforge.net/svnroot/colossus/trunk/Colossus
-Source0:        colossus-%{revdate}-%{rev}.tar.gz
+Source0:        colossus-%{branch}-%{revdate}-%{rev}.tar.gz
 Source1:        colossus-gen-tarball.sh
 Source2:        colossus-rev.xsl
 
@@ -63,7 +64,7 @@ Requires:       jpackage-utils
 This package contains the API documentation for %{name}.
 
 %prep
-%setup -q -n %{name}-%{revdate}-%{rev}
+%setup -q -n %{name}-%{branch}-%{revdate}-%{rev}
 
 %build
 
@@ -179,6 +180,18 @@ touch --no-create %{_datadir}/pixmaps ||
 
 %changelog
 
+* Fri Oct 16 2009 Bruno Wolff III <bruno at wolff.to> - 0.9.3-1
+- Rebase to 0.9.3
+- Adjust script for grabbing source to be able to grab from branches
+- Fixed 2877055: Some GUI preferences don't load on startup
+- Fixed: 2864777 Illegal rangestrike over walls
+- Do not choose Experimental AI as "A Random AI" because it occasionally crashes
+- Fixed: 2859914 Balrog placement ignores score (aka: Balrog every 300 again, not 50)
+- Fixed: 2864790 Aborting load game with remote player - No GetPlayers dialog
+- Fixed: 2838276 "my Strike Skill" is wrong for nonnatives to bramble (actually, just improved the dialog to make it's meaning clearer)
+- Fixed: 2855208 Balrog exception in V0.9.2 (ConcurrentModificationException)
+- See: http://colossus.sourceforge.net/docs/RecentChangesDetails.html
+
 * Sun Sep 06 2009 Bruno Wolff III <bruno at wolff.to> - 0.9.2-1.20090906svn4519
 - Rebase to 0.9.2
 - See: http://colossus.sourceforge.net/docs/RecentChangesDetails.html


Index: import.log
===================================================================
RCS file: /cvs/pkgs/rpms/colossus/F-10/import.log,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -p -r1.4 -r1.5
--- import.log	6 Sep 2009 16:49:49 -0000	1.4
+++ import.log	17 Oct 2009 00:58:34 -0000	1.5
@@ -2,3 +2,4 @@ colossus-0-0_2_20090710svn4432_fc11:F-10
 colossus-0_9_0-1_20090810svn4482_fc11:F-10:colossus-0.9.0-1.20090810svn4482.fc11.src.rpm:1249969651
 colossus-0_9_1-1_20090817svn4489_fc11:F-10:colossus-0.9.1-1.20090817svn4489.fc11.src.rpm:1250541400
 colossus-0_9_2-1_20090906svn4519_fc11:F-10:colossus-0.9.2-1.20090906svn4519.fc11.src.rpm:1252255765
+colossus-0_9_3-1_fc12:F-10:colossus-0.9.3-1.fc12.src.rpm:1255741098


Index: sources
===================================================================
RCS file: /cvs/pkgs/rpms/colossus/F-10/sources,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -p -r1.5 -r1.6
--- sources	6 Sep 2009 16:49:49 -0000	1.5
+++ sources	17 Oct 2009 00:58:34 -0000	1.6
@@ -1 +1 @@
-29662adb0e19e4eeea4c0f5c6942c477  colossus-20090906-4519.tar.gz
+678d68e4c356c69987342d833dd702a0  colossus-0.9.3-20091015-4577.tar.gz




More information about the fedora-extras-commits mailing list
Index: colossus-gen-tarball.sh
===================================================================
RCS file: /cvs/pkgs/rpms/colossus/F-10/colossus-gen-tarball.sh,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -p -r1.1 -r1.2
--- colossus-gen-tarball.sh	13 Jul 2009 03:18:19 -0000	1.1
+++ colossus-gen-tarball.sh	17 Oct 2009 00:58:34 -0000	1.2
@@ -6,9 +6,20 @@
 # is used instead.
 # $REV[0] is the date of the commit for the build
 # $REV[1] is the revision of the commit for the build
+# If a rev is provided, you can also provide a branch. As time goes on
+# I expect that the Colossus project will be doing more stable branches.
+# Don't supply "trunk" as a branch, leave it unspecified instead.
 
 # Location of SVN repository
-COLOSSUS=https://colossus.svn.sourceforge.net/svnroot/colossus/trunk/Colossus
+if test -z "$2"
+then
+BRANCH=trunk/Colossus
+BNAME=
+else
+BRANCH=branches/releases/Colossus-$2
+BNAME=$2
+fi
+COLOSSUS=https://colossus.svn.sourceforge.net/svnroot/colossus/${BRANCH}
 
 # First check if revision specified
 if test -z "$1"
@@ -19,24 +30,24 @@ REV=(`svn info -r $1 --xml --incremental
 fi
 
 # Remove pre-existing source with the same rev
-rm -rf colossus-${REV[0]}-${REV[1]}.tar.gz colossus-${REV[0]}-${REV[1]}
+rm -rf colossus-${BNAME}-${REV[0]}-${REV[1]}.tar.gz colossus-${BNAME}-${REV[0]}-${REV[1]}
 
 # Fetch source
-svn export -q -r ${REV[1]} $COLOSSUS colossus-${REV[0]}-${REV[1]}
+svn export -q -r ${REV[1]} $COLOSSUS colossus-${BNAME}-${REV[0]}-${REV[1]}
 
 # Remove included jar files
-find colossus-${REV[0]}-${REV[1]} -name '*.jar' | xargs rm -f
+find colossus-${BNAME}-${REV[0]}-${REV[1]} -name '*.jar' | xargs rm -f
 
 # Remove htdocs is just a copy of the project home page. This is also
 # one less set of images to worry about.
-rm -rf colossus-${REV[0]}-${REV[1]}/htdocs
+rm -rf colossus-${BNAME}-${REV[0]}-${REV[1]}/htdocs
 
 # This can be used to remove all of the unused images in the icons directory.
 # It is not needed for now.
 # find colossus-${REV[0]}-${REV[1]}/core/src/main/resource/icons/ -type f \! -name ColossusIcon.png | xargs rm -f
 
 # Build .tar.gz archive
-tar czf colossus-${REV[0]}-${REV[1]}.tar.gz colossus-${REV[0]}-${REV[1]}
+tar czf colossus-${BNAME}-${REV[0]}-${REV[1]}.tar.gz colossus-${BNAME}-${REV[0]}-${REV[1]}
 
 # Remove unarchived source
-rm -rf colossus-${REV[0]}-${REV[1]}
+rm -rf colossus-${BNAME}-${REV[0]}-${REV[1]}
@@ -19,24 +30,24 @@ REV=(`svn info -r $1 --xml --incremental
 # This can be used to remove all of the unused images in the icons directory.
 # It is not needed for now.
-# find colossus-${REV[0]}-${REV[1]}/core/src/main/resource/icons/ -type f \! -name ColossusIcon.png | xargs rm -f
+# find colossus-${BNAME}-${REV[0]}-${REV[1]}/core/src/main/resource/icons/ -type f \! -name ColossusIcon.png | xargs rm -f
 
 # Build .tar.gz archive

